Message class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
- Message({required String role, String? content, ToolCall? toolCall, ToolResult? toolResult})
-
constfactory
-
Message.fromJson(Map<
String, Object?> json) -
factory
Properties
- content → String?
-
no setterinherited
-
copyWith
→ $MessageCopyWith<
Message> -
Create a copy of Message
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- role → String
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toolCall → ToolCall?
-
no setterinherited
- toolResult → ToolResult?
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_Message value)) → TResult -
Available on Message, provided by the MessagePatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_Message value)?) → TResult? -
Available on Message, provided by the MessagePatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_Message value)?, {required TResult orElse()}) → TResult -
Available on Message, provided by the MessagePatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String role, String? content, ToolCall? toolCall, ToolResult? toolResult)?, {required TResult orElse()}) → TResult -
Available on Message, provided by the MessagePatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this Message to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String role, String? content, ToolCall? toolCall, ToolResult? toolResult)) → TResult -
Available on Message, provided by the MessagePatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String role, String? content, ToolCall? toolCall, ToolResult? toolResult)?) → TResult? -
Available on Message, provided by the MessagePatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited