Prosody class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
- Prosody({required EmotionScores scores})
-
constfactory
-
Prosody.fromJson(Map<
String, Object?> json) -
factory
Properties
-
copyWith
→ $ProsodyCopyWith<
Prosody> -
Create a copy of Prosody
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scores → EmotionScores
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_Prosody value)) → TResult -
Available on Prosody, provided by the ProsodyPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_Prosody value)?) → TResult? -
Available on Prosody, provided by the ProsodyPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_Prosody value)?, {required TResult orElse()}) → TResult -
Available on Prosody, provided by the ProsodyPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(EmotionScores scores)?, {required TResult orElse()}) → TResult -
Available on Prosody, provided by the ProsodyPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this Prosody to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(EmotionScores scores)) → TResult -
Available on Prosody, provided by the ProsodyPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(EmotionScores scores)?) → TResult? -
Available on Prosody, provided by the ProsodyPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited