ToolCall class abstract

Available extensions
Annotations
  • @freezed

Constructors

ToolCall({required String name, required String parameters, required bool responseRequired, required String toolCallId, String? customSessionId, String? toolType})
const
factory
ToolCall.fromJson(Map<String, Object?> json)
factory

Properties

copyWith → $ToolCallCopyWith<ToolCall>
Create a copy of ToolCall with the given fields replaced by the non-null parameter values.
no setterinherited
customSessionId String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
name String
no setterinherited
parameters String
no setterinherited
responseRequired bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolCallId String
no setterinherited
toolType String?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ToolCall value)) → TResult

Available on ToolCall, provided by the ToolCallPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ToolCall value)?) → TResult?

Available on ToolCall, provided by the ToolCallPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ToolCall value)?, {required TResult orElse()}) → TResult

Available on ToolCall, provided by the ToolCallPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String name, String parameters, bool responseRequired, String toolCallId, String? customSessionId, String? toolType)?, {required TResult orElse()}) → TResult

Available on ToolCall, provided by the ToolCallPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ToolCall to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String name, String parameters, bool responseRequired, String toolCallId, String? customSessionId, String? toolType)) → TResult

Available on ToolCall, provided by the ToolCallPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String name, String parameters, bool responseRequired, String toolCallId, String? customSessionId, String? toolType)?) → TResult?

Available on ToolCall, provided by the ToolCallPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited