ContextSettings class abstract

Available extensions
Annotations
  • @freezed

Constructors

ContextSettings({required String text, ContextType? type})
const
factory
ContextSettings.fromJson(Map<String, Object?> json)
factory

Properties

copyWith → $ContextSettingsCopyWith<ContextSettings>
Create a copy of ContextSettings with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
no setterinherited
type ContextType?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ContextSettings value)) → TResult

Available on ContextSettings, provided by the ContextSettingsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ContextSettings value)?) → TResult?

Available on ContextSettings, provided by the ContextSettingsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ContextSettings value)?, {required TResult orElse()}) → TResult

Available on ContextSettings, provided by the ContextSettingsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String text, ContextType? type)?, {required TResult orElse()}) → TResult

Available on ContextSettings, provided by the ContextSettingsPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ContextSettings to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String text, ContextType? type)) → TResult

Available on ContextSettings, provided by the ContextSettingsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String text, ContextType? type)?) → TResult?

Available on ContextSettings, provided by the ContextSettingsPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited