ChatPagedEvents class abstract

Available extensions
Annotations
  • @freezed

Constructors

ChatPagedEvents({required String chatGroupId, required List<ChatEvent> eventsPage, required String id, required int pageNumber, required int pageSize, required PaginationDirection paginationDirection, required int startTimestamp, required ChatStatus status, required int totalPages, ConfigSpec? config, int? endTimestamp, String? metadata})
const
factory
ChatPagedEvents.fromJson(Map<String, Object?> json)
factory

Properties

chatGroupId String
no setterinherited
config ConfigSpec?
no setterinherited
copyWith → $ChatPagedEventsCopyWith<ChatPagedEvents>
Create a copy of ChatPagedEvents with the given fields replaced by the non-null parameter values.
no setterinherited
endDateTime DateTime?

Available on ChatPagedEvents, provided by the ChatPagedEventsX extension

no setter
endTimestamp int?
no setterinherited
eventsPage List<ChatEvent>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String
no setterinherited
metadata String?
no setterinherited
pageNumber int
no setterinherited
pageSize int
no setterinherited
paginationDirection PaginationDirection
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startDateTime DateTime

Available on ChatPagedEvents, provided by the ChatPagedEventsX extension

no setter
startTimestamp int
no setterinherited
status ChatStatus
no setterinherited
totalPages int
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ChatPagedEvents value)) → TResult

Available on ChatPagedEvents, provided by the ChatPagedEventsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ChatPagedEvents value)?) → TResult?

Available on ChatPagedEvents, provided by the ChatPagedEventsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ChatPagedEvents value)?, {required TResult orElse()}) → TResult

Available on ChatPagedEvents, provided by the ChatPagedEventsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String chatGroupId, List<ChatEvent> eventsPage, String id, int pageNumber, int pageSize, PaginationDirection paginationDirection, int startTimestamp, ChatStatus status, int totalPages, ConfigSpec? config, int? endTimestamp, String? metadata)?, {required TResult orElse()}) → TResult

Available on ChatPagedEvents, provided by the ChatPagedEventsPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ChatPagedEvents to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String chatGroupId, List<ChatEvent> eventsPage, String id, int pageNumber, int pageSize, PaginationDirection paginationDirection, int startTimestamp, ChatStatus status, int totalPages, ConfigSpec? config, int? endTimestamp, String? metadata)) → TResult

Available on ChatPagedEvents, provided by the ChatPagedEventsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String chatGroupId, List<ChatEvent> eventsPage, String id, int pageNumber, int pageSize, PaginationDirection paginationDirection, int startTimestamp, ChatStatus status, int totalPages, ConfigSpec? config, int? endTimestamp, String? metadata)?) → TResult?

Available on ChatPagedEvents, provided by the ChatPagedEventsPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited