QueryParameters class abstract
variables, e.g wss://api.hume.ai/v0/evi/chat?session_settingsDATE_DURATION_MINUTES=10
- Available extensions
- Annotations
-
- @freezed
Constructors
- QueryParameters({@JsonKey.new(name: 'access_token') String? accessToken, @JsonKey.new(name: 'config_id') String? configId, @JsonKey.new(name: 'config_version') int? configVersion, @JsonKey.new(name: 'event_limit') int? eventLimit, @JsonKey.new(name: 'resumed_chat_group_id') String? resumedChatGroupId, @JsonKey.new(name: 'verbose_transcription') bool? verboseTranscription, @JsonKey.new(name: 'api_key') String? apiKey, @JsonKey.new(name: 'session_settings[audio][channels]') int? audioChannels, @JsonKey.new(name: 'session_settings[audio][encoding]') String? audioEncoding, @JsonKey.new(name: 'session_settings[audio][sample_rate]') int? audioSampleRate, @JsonKey.new(name: 'session_settings[context][text]') String? contextText, @JsonKey.new(name: 'session_settings[context][type]') String? contextType, @JsonKey.new(name: 'session_settings[custom_session_id]') String? customSessionId, @JsonKey.new(name: 'session_settings[event_limit]') int? sessionEventLimit, @JsonKey.new(name: 'session_settings[language_model_api_key]') String? languageModelApiKey, @JsonKey.new(name: 'session_settings[voice_id]') String? voiceId})
-
constfactory
-
QueryParameters.fromJson(Map<
String, Object?> json) -
factory
Properties
- accessToken → String?
-
no setterinherited
- apiKey → String?
-
no setterinherited
- audioChannels → int?
-
no setterinherited
- audioEncoding → String?
-
no setterinherited
- audioSampleRate → int?
-
no setterinherited
- configId → String?
-
no setterinherited
- configVersion → int?
-
no setterinherited
- contextText → String?
-
no setterinherited
- contextType → String?
-
no setterinherited
-
copyWith
→ $QueryParametersCopyWith<
QueryParameters> -
Create a copy of QueryParameters
with the given fields replaced by the non-null parameter values.
no setterinherited
- customSessionId → String?
-
no setterinherited
- eventLimit → int?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- languageModelApiKey → String?
-
no setterinherited
- resumedChatGroupId → String?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionEventLimit → int?
-
no setterinherited
- verboseTranscription → bool?
-
no setterinherited
- voiceId → String?
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_QueryParameters value)) → TResult -
Available on QueryParameters, provided by the QueryParametersPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_QueryParameters value)?) → TResult? -
Available on QueryParameters, provided by the QueryParametersPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_QueryParameters value)?, {required TResult orElse()}) → TResult -
Available on QueryParameters, provided by the QueryParametersPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String? accessToken, String? configId, int? configVersion, int? eventLimit, String? resumedChatGroupId, bool? verboseTranscription, String? apiKey, int? audioChannels, String? audioEncoding, int? audioSampleRate, String? contextText, String? contextType, String? customSessionId, int? sessionEventLimit, String? languageModelApiKey, String? voiceId)?, {required TResult orElse()}) → TResult -
Available on QueryParameters, provided by the QueryParametersPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this QueryParameters to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String? accessToken, String? configId, int? configVersion, int? eventLimit, String? resumedChatGroupId, bool? verboseTranscription, String? apiKey, int? audioChannels, String? audioEncoding, int? audioSampleRate, String? contextText, String? contextType, String? customSessionId, int? sessionEventLimit, String? languageModelApiKey, String? voiceId)) → TResult -
Available on QueryParameters, provided by the QueryParametersPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String? accessToken, String? configId, int? configVersion, int? eventLimit, String? resumedChatGroupId, bool? verboseTranscription, String? apiKey, int? audioChannels, String? audioEncoding, int? audioSampleRate, String? contextText, String? contextType, String? customSessionId, int? sessionEventLimit, String? languageModelApiKey, String? voiceId)?) → TResult? -
Available on QueryParameters, provided by the QueryParametersPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited