ToolResult class sealed
- Available extensions
- Annotations
-
- @freezed
Constructors
- ToolResult.error({required String error, required String toolCallId, String? code, String? content, String? customSessionId, String? level, String? toolType})
-
constfactory
-
ToolResult.fromJson(Map<
String, Object?> json) -
factory
- ToolResult.response({required String content, required String toolCallId, String? customSessionId, String? toolName, String? toolType})
-
constfactory
Properties
- content → String?
-
no setterinherited
-
copyWith
→ $ToolResultCopyWith<
ToolResult> -
Create a copy of ToolResult
with the given fields replaced by the non-null parameter values.
no setterinherited
- customSessionId → String?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toolCallId → String
-
no setterinherited
- toolType → String?
-
no setterinherited
Methods
-
map<
TResult extends Object?> ({required TResult response(_ToolResponse value), required TResult error(_ToolError value)}) → TResult -
Available on ToolResult, provided by the ToolResultPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> ({TResult? response(_ToolResponse value)?, TResult? error(_ToolError value)?}) → TResult? -
Available on ToolResult, provided by the ToolResultPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> ({TResult response(_ToolResponse value)?, TResult error(_ToolError value)?, required TResult orElse()}) → TResult -
Available on ToolResult, provided by the ToolResultPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> ({TResult response(String content, String toolCallId, String? customSessionId, String? toolName, String? toolType)?, TResult error(String error, String toolCallId, String? code, String? content, String? customSessionId, String? level, String? toolType)?, required TResult orElse()}) → TResult -
Available on ToolResult, provided by the ToolResultPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this ToolResult to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> ({required TResult response(String content, String toolCallId, String? customSessionId, String? toolName, String? toolType), required TResult error(String error, String toolCallId, String? code, String? content, String? customSessionId, String? level, String? toolType)}) → TResult -
Available on ToolResult, provided by the ToolResultPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> ({TResult? response(String content, String toolCallId, String? customSessionId, String? toolName, String? toolType)?, TResult? error(String error, String toolCallId, String? code, String? content, String? customSessionId, String? level, String? toolType)?}) → TResult? -
Available on ToolResult, provided by the ToolResultPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited