ChatEvent class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
- ChatEvent({required String chatId, required String id, required ChatEventRole role, required int timestamp, required ChatEventType type, String? emotionFeatures, String? messageText, String? metadata, })
-
constfactory
-
ChatEvent.fromJson(Map<
String, Object?> json) -
factory
Properties
- chatId → String
-
no setterinherited
-
copyWith
→ $ChatEventCopyWith<
ChatEvent> -
Create a copy of ChatEvent
with the given fields replaced by the non-null parameter values.
no setterinherited
- dateTime → DateTime
-
Available on ChatEvent, provided by the ChatEventX extension
no setter - emotionFeatures → String?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
no setterinherited
- messageText → String?
-
no setterinherited
- metadata → String?
-
no setterinherited
-
no setterinherited
- role → ChatEventRole
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → int
-
no setterinherited
- type → ChatEventType
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_ChatEvent value)) → TResult -
Available on ChatEvent, provided by the ChatEventPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_ChatEvent value)?) → TResult? -
Available on ChatEvent, provided by the ChatEventPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_ChatEvent value)?, {required TResult orElse()}) → TResult -
Available on ChatEvent, provided by the ChatEventPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String chatId, String id, ChatEventRole role, int timestamp, ChatEventType type, String? emotionFeatures, String? messageText, String? metadata, )?, {required TResult orElse()}) → TResult -
Available on ChatEvent, provided by the ChatEventPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this ChatEvent to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String chatId, String id, ChatEventRole role, int timestamp, ChatEventType type, String? emotionFeatures, String? messageText, String? metadata, )) → TResult -
Available on ChatEvent, provided by the ChatEventPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String chatId, String id, ChatEventRole role, int timestamp, ChatEventType type, String? emotionFeatures, String? messageText, String? metadata, )?) → TResult? -
Available on ChatEvent, provided by the ChatEventPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited